// Copyright (c) 2009-2018 LG Electronics, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

#include "AbstractCallback.h"

#include "activity/Activity.h"

AbstractCallback::AbstractCallback(std::shared_ptr<Activity> activity)
    : m_serial(kUnassignedSerial)
    , m_activity(activity)
{
}

AbstractCallback::~AbstractCallback()
{
}

void AbstractCallback::failed(FailureType failure)
{
    if (!m_activity.expired()) {
        m_activity.lock()->callbackFailed(shared_from_this(), failure);
    }
}

void AbstractCallback::succeeded()
{
    if (!m_activity.expired()) {
        m_activity.lock()->callbackSucceeded(shared_from_this());
    }
}

unsigned AbstractCallback::getSerial() const
{
    return m_serial;
}

void AbstractCallback::setSerial(unsigned serial)
{
    m_serial = serial;
}

